X509 v0.7.0 X509.CRL.Entry View Source

CRL entries identify revoked certificates and contain metadata about the revocation.

Link to this section Summary

Types

t()

:TBSCertList_revokedCertificates_SEQOF record, as used in Erlang's :public_key module

Functions

Looks up a specific extension in a CRL entry.

Returns the list of extensions in a CRL entry.

Returns a new CRL entry for the given certificate or serial number. The revocation date must be specified, and additional metadata may be specified as one or more X509.CRL.Extension entries.

Returns the certificate recocation date for a CRL entry.

Returns the certificate serial number for a CRL entry.

Link to this section Types

:TBSCertList_revokedCertificates_SEQOF record, as used in Erlang's :public_key module

Link to this section Functions

Link to this function

extension(entry, extension_id)

View Source (since 0.5.0)

Looks up a specific extension in a CRL entry.

The desired extension can be specified as an atom or an OID value. Returns nil if the specified extension is not present in the CRL entry.

Link to this function

extensions(arg)

View Source (since 0.5.0)
extensions(t()) :: [X509.CRL.Extension.t()]

Returns the list of extensions in a CRL entry.

Link to this function

new(certificate, date, extensions \\ [])

View Source (since 0.5.0)

Returns a new CRL entry for the given certificate or serial number. The revocation date must be specified, and additional metadata may be specified as one or more X509.CRL.Extension entries.

Link to this function

revocation_date(arg)

View Source (since 0.5.0)
revocation_date(t()) :: DateTime.t()

Returns the certificate recocation date for a CRL entry.

Link to this function

serial(arg)

View Source (since 0.5.0)
serial(t()) :: pos_integer()

Returns the certificate serial number for a CRL entry.